summaryrefslogtreecommitdiff
path: root/src/portable/microchip/samg
diff options
context:
space:
mode:
authorhathach <[email protected]>2019-11-28 13:39:29 +0700
committerhathach <[email protected]>2019-11-28 13:39:29 +0700
commitd7558e8a0f12c685f2690c985e5f75df0777065b (patch)
tree2bc43b629a9e184319592afbd65e49fadb3280da /src/portable/microchip/samg
parentac701c398b4e9a43eefe0ee0be38579ca17535df (diff)
use dcd_edpt0_status_complete() to set address without blocking for samd21/samd51/stm32_fsdev
Diffstat (limited to 'src/portable/microchip/samg')
-rw-r--r--src/portable/microchip/samg/dcd_samg.c5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/portable/microchip/samg/dcd_samg.c b/src/portable/microchip/samg/dcd_samg.c
index c38621e00..122dc04b7 100644
--- a/src/portable/microchip/samg/dcd_samg.c
+++ b/src/portable/microchip/samg/dcd_samg.c
@@ -120,7 +120,10 @@ void dcd_set_address (uint8_t rhport, uint8_t dev_addr)
(void) rhport;
(void) dev_addr;
- // SAMG can only set address after status for this request is complete
+ // Response with zlp status
+ dcd_edpt_xfer(rhport, 0x80, NULL, 0);
+
+ // DCD can only set address after status for this request is complete.
// do it at dcd_edpt0_status_complete()
}